AsyncQueryMsgFns

Trait AsyncQueryMsgFns 

pub trait AsyncQueryMsgFns<Chain: AsyncWasmQuerier + ChainState, CwOrchQueryMsgType: Sync>: AsyncCwOrchQuery<Chain, QueryMsg = CwOrchQueryMsgType>
where QueryMsg: Into<CwOrchQueryMsgType>,
{ // Provided methods async fn block_max_gas_async(&self) -> Result<Uint64, CwEnvError> { ... } async fn proxy_code_id_async(&self) -> Result<Uint64, CwEnvError> { ... } }
Automatically derived trait that allows you to call the variants of the message directly without the need to construct the struct yourself.

Provided Methods

async fn block_max_gas_async(&self) -> Result<Uint64, CwEnvError>

Automatically generated wrapper around QueryMsg::BlockMaxGas variant

async fn proxy_code_id_async(&self) -> Result<Uint64, CwEnvError>

Automatically generated wrapper around QueryMsg::ProxyCodeId variant

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<Chain: AsyncWasmQuerier + ChainState, CwOrchQueryMsgType: Sync, SupportedContract> AsyncQueryMsgFns<Chain, CwOrchQueryMsgType> for SupportedContract
where QueryMsg: Into<CwOrchQueryMsgType>, SupportedContract: AsyncCwOrchQuery<Chain, QueryMsg = CwOrchQueryMsgType>,

Available on non-WebAssembly only.